@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0501';
+our $VERSION = '0.0502';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -150,9 +150,9 @@ sub generate {
     my $v; # Vertex
     for my $n (1 .. $self->max) {
         $v = $self->_next_successor($n, $v);
-        push @progression, $v if $v; # XXX Is this right?
+        push @progression, $v;
     }
-    print "Progression: @progression\n" if $self->verbose;
+    print 'Progression: ', ddc(\@progression) if $self->verbose;
 
     my @chord_map = @{ $self->chord_map };
 
@@ -167,9 +167,10 @@ sub generate {
             $i++;
         }
     }
+    print 'Chord map: ', ddc(\@chord_map) if $self->verbose;
 
     my @phrase = map { $self->_tt_sub(\@chord_map, $_) } @progression;
-    print "Phrase: @phrase\n" if $self->verbose;
+    print 'Phrase: ', ddc(\@phrase) if $self->verbose;
 
     # Add octaves to the chords
     my $mcn = Music::Chord::Note->new;
@@ -221,7 +222,7 @@ sub _next_successor {
     }
     elsif ($n == $self->max) {
         if ($self->resolve == 0) {
-            $s = $self->graph->random_successor($n - 1);
+            $s = $self->graph->random_successor($v) || $self->_full_keys;
         }
         elsif ($self->resolve == 1) {
             $s = 1;
@@ -317,7 +318,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0501
+version 0.0502
 
 =head1 SYNOPSIS
 
@@ -501,8 +502,8 @@ Show the B<generate> and B<substitute> progress.
 
   $prog = Music::Chord::Progression->new( # Override the defaults
     max        => 4,
-    net        => { 1 => [...], ... 6 => [...] },
-    chord_map  => ['m','','m','m','',''],
+    net        => { 1 => [...], ... 7 => [...] },
+    chord_map  => ['m','dim','','m','m','',''],
     scale_name => 'minor',
     scale_note => 'A',
     octave     => 5,
